pub fn is_main_thread_registered() -> boolExpand description
Reports whether a thread has been registered as the polyfill main thread by
executor::start_main_executor, regardless of which thread asks.
pub fn is_main_thread_registered() -> boolReports whether a thread has been registered as the polyfill main thread by
executor::start_main_executor, regardless of which thread asks.